Tests for normality — STAC 0.7 documentation

### Navigation

- index
- next |
- previous |
- STAC 0.7 documentation »

# Tests for normality

`shapiro`(x[, a, reta]) | Perform the Shapiro-Wilk test for normality.
`normaltest`(a[, axis]) | Tests whether a sample differs from a normal distribution.
`kstest`(rvs, cdf[, args, N, alternative, mode]) | Perform the Kolmogorov-Smirnov test for goodness of fit.

### Navigation

- index
- next |
- previous |
- STAC 0.7 documentation »